=======
Credits
=======

Development and Proyect Lead
----------------------------

* Rodrigo Gadea <matematica.a3k@gmail.com>

Artwork Contributors
--------------------

None yet. Why not be the first?

Code Contributors
-----------------

None yet. Why not be the first?

Documentation Contributors
--------------------------

None yet. Why not be the first?

Monetary Contributors
---------------------

None yet. Why not be the first?

Non-Monetary Contributors
-------------------------

None yet. Why not be the first?

Promotion Contributors
----------------------

None yet. Why not be the first?

Others
------

Tools used in rendering this package
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*  Cookiecutter_
*  `cookiecutter-djangopackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-djangopackage`: https://github.com/pydanny/cookiecutter-djangopackage
